@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: runs.h,v 1.7 2013-04-28 16:30:42 dick Exp $
+	$Id: runs.h,v 1.13 2016-07-31 18:55:44 dick Exp $
 */
 
 /*	Although all other segments of data in this program are described by
@@ -13,24 +13,25 @@
 */
 
 struct chunk {
-	/* a chunk of text in various representations */
-	struct text *ch_text;		/* pointer to the file */
+	/* a chunk of text */
+	const struct text *ch_text;	/* pointer to the file */
 	struct position ch_first;	/* first in chunk */
 	struct position ch_last;	/* last in chunk */
 };
 
 struct run {				/* a 'run' of coincident tokens */
+	struct run *rn_next;
 	struct chunk rn_chunk0;		/* chunk in left file */
 	struct chunk rn_chunk1;		/* chunk in right file */
 	size_t rn_size;
 };
 
-#define	AISO_TYPE	struct run *
-#define	AISO_ITER
-
-#include	"aiso.spc"
-
-extern void add_to_runs(struct run *r);
+extern void add_to_runs(
+    struct text *txt0, size_t i0, struct text *txt1, size_t i1,
+    size_t size);
+extern struct run *sorted_runs(void);
+extern struct run *unsorted_runs(void);
+extern void discard_runs(void);
 
 #ifdef	DB_RUN
 extern void db_run_info(const char *msg, const struct run *run, int lines_too);
